import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { select, axisLeft, axisBottom, csv, arc, pie, scaleBand, scaleLinear, max, scaleOrdinal, schemeCategory10, format} from 'd3';

const svg = select("svg");
const width = +svg.attr('width');
const height = +svg.attr('height');

const numberFormat = number =>
  	(Math.abs(Number(number)) /1.0e+6).toFixed(2) + " Million" ;

const render = data => {
  const pieData = pie().sort(null).value(d=>d.Customer)(data);
  const colors = scaleOrdinal(schemeCategory10);
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(20)
  	.padAngle(0)
  	.padRadius(0);
  
  const sections = svg.append("g")
  	.attr("transform", `translate(250,250)`)
  	.selectAll("path").data(pieData);
  sections.enter().append("path").attr("d", segments)
  	.attr("fill", d => colors(d.data.Customer))
  	.on("mouseover", d => console.log(d.data.Customer));
  
  const legends = svg.append("g")
  	.attr("transform", "translate(500,100)")
    .selectAll(".legends").data(pieData);
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*30})`;
    });
  
  legend.append("rect").attr("width",20).attr("height",20)
  	.attr("fill", d => colors(d.data.Customer));
  legend.append("text")
  	.attr("x", 25)
  	.attr("y", 15)
  	.attr("class","legend_text")
  	.text(d => d.data.state);
  legend.append("text")
  	.attr("x", 250)
  	.attr("y", 15)
  	.attr("class","legend_value")
  	.text(d=>numberFormat(d.data.Customer));
}

const csvUrl =
  'https://gist.githubusercontent.com/NITIN0601/ff53b9c72da60dc3393810b84971cac2/raw/ca0c5612430ea9d9d8705e21cd140b4da890fa9f/Tesla%2520Year%2520wise%2520sales.csv'

csv(csvUrl).then(csvData => {
    csvData.sort((data1, data2) => data2.Customer-data1.Customer);
    if (csvData) {
      render(csvData.slice(0, 10));
    }
});
